==> nextcloud-12.0.3-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/cs.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Komentáře",
    "Unknown user" : "Neznámý uživatel",
    "New comment …" : "Nový komentář ...",
    "Delete comment" : "Smazat komentář",
    "Post" : "Zveřejnit",
    "Cancel" : "Zrušit",
    "Edit comment" : "Upravit komentář",
    "[Deleted user]" : "[Smazaný uživatel]",
    "No comments yet, start the conversation!" : "Zatím bez komentářů, začněte konverzaci!",
    "More comments …" : "Více komentářů ...",
    "Save" : "Uložit",
    "Allowed characters {count} of {max}" : "Povolených znaků {count} z {max}",
    "Error occurred while retrieving comment with id {id}" : "Došlo k chybě při načítání komentáře s id {id}",
    "Error occurred while updating comment with id {id}" : "Došlo k chybě při aktualizování komentáře s id {id}",
    "Error occurred while posting comment" : "Došlo k chybě při zveřejňování komentáře",
    "_%n unread comment_::_%n unread comments_" : ["%n nepřečtený komentář","%n nepřečtené komentáře","%n nepřečtených komentářů"],
    "Comment" : "Komentář",
    "You commented" : "Okomentoval(a) jsi",
    "%1$s commented" : "%1$s okomentován",
    "{author} commented" : "{author} okomentoval(a)",
    "You commented on %1$s" : "Okomentoval(a) jste %1$s",
    "You commented on {file}" : "Okomentoval(a) jste {file}",
    "%1$s commented on %2$s" : "%1$s okomentoval %2$s",
    "{author} commented on {file}" : "{author} okomentoval(a) {file}",
    "<strong>Comments</strong> for files" : "<strong>Komentáře</strong> souborů",
    "A (now) deleted user mentioned you in a comment on “%s”" : "A (now) deleted user mentioned you in a comment on “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Nyní již smazaný uživatel vás zmínil v komentáři u \"{file}\"",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s vás zmínil(a) v komentáři u %2$s",
    "{user} mentioned you in a comment on “{file}”" : "{user} vás zmínil v komentáři u “{file}”"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> nextcloud-12.0.4-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/cs.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Komentáře",
    "Unknown user" : "Neznámý uživatel",
    "New comment …" : "Nový komentář ...",
    "Delete comment" : "Smazat komentář",
    "Post" : "Zveřejnit",
    "Cancel" : "Zrušit",
    "Edit comment" : "Upravit komentář",
    "[Deleted user]" : "[Smazaný uživatel]",
    "No comments yet, start the conversation!" : "Zatím bez komentářů, začněte konverzaci!",
    "More comments …" : "Více komentářů ...",
    "Save" : "Uložit",
    "Allowed characters {count} of {max}" : "Povolených znaků {count} z {max}",
    "Error occurred while retrieving comment with id {id}" : "Došlo k chybě při načítání komentáře s id {id}",
    "Error occurred while updating comment with id {id}" : "Došlo k chybě při aktualizování komentáře s id {id}",
    "Error occurred while posting comment" : "Došlo k chybě při zveřejňování komentáře",
    "_%n unread comment_::_%n unread comments_" : ["%n nepřečtený komentář","%n nepřečtené komentáře","%n nepřečtených komentářů"],
    "Comment" : "Komentář",
    "You commented" : "Okomentoval(a) jsi",
    "%1$s commented" : "%1$s okomentován",
    "{author} commented" : "{author} okomentoval(a)",
    "You commented on %1$s" : "Okomentoval(a) jste %1$s",
    "You commented on {file}" : "Okomentoval(a) jste {file}",
    "%1$s commented on %2$s" : "%1$s okomentoval %2$s",
    "{author} commented on {file}" : "{author} okomentoval(a) {file}",
    "<strong>Comments</strong> for files" : "<strong>Komentáře</strong> souborů",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Byli jste zmíněni v “%s”, v komentáři od uživatele, který byl později smazán",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Byli jste zmíněni v souboru “{file}”, v komentáři od uživatele, který byl později smazán",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s vás zmínil(a) v komentáři u %2$s",
    "{user} mentioned you in a comment on “{file}”" : "{user} vás zmínil v komentáři u “{file}”",
    "A (now) deleted user mentioned you in a comment on “%s”" : "A (now) deleted user mentioned you in a comment on “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Nyní již smazaný uživatel vás zmínil v komentáři u \"{file}\""
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
